@@ -1,8 +1,6 @@
 package Moose::Exception::CallingReadOnlyMethodOnAnImmutableInstance;
-BEGIN {
-  $Moose::Exception::CallingReadOnlyMethodOnAnImmutableInstance::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CallingReadOnlyMethodOnAnImmutableInstance::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -17,4 +15,5 @@ sub _build_message {
     "The '".$self->method_name."' method is read-only when called on an immutable instance";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
