@@ -1,8 +1,6 @@
 package Moose::Exception::HandlesMustBeAHashRef;
-BEGIN {
-  $Moose::Exception::HandlesMustBeAHashRef::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::HandlesMustBeAHashRef::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Instance';
@@ -18,4 +16,5 @@ sub _build_message {
     "The 'handles' option must be a HASH reference, not ".$self->given_handles;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
