@@ -1,8 +1,6 @@
 package Moose::Exception::RolesDoNotSupportExtends;
-BEGIN {
-  $Moose::Exception::RolesDoNotSupportExtends::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::RolesDoNotSupportExtends::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -10,4 +8,5 @@ sub _build_message {
     "Roles do not support 'extends' (you can use 'with' to specialize a role)";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
