@@ -1,18 +1,22 @@
 package Class::MOP::Mixin;
-BEGIN {
-  $Class::MOP::Mixin::AUTHORITY = 'cpan:STEVAN';
-}
-$Class::MOP::Mixin::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use strict;
 use warnings;
 
 use Scalar::Util 'blessed';
+use Module::Runtime 'use_module';
 
 sub meta {
     require Class::MOP::Class;
     Class::MOP::Class->initialize( blessed( $_[0] ) || $_[0] );
 }
 
+sub _throw_exception {
+    my ($class, $exception_type, @args_to_exception) = @_;
+    die use_module( "Moose::Exception::$exception_type" )->new( @args_to_exception );
+}
+
 1;
 
 # ABSTRACT: Base class for mixin classes
@@ -29,23 +33,23 @@ Class::MOP::Mixin - Base class for mixin classes
 
 =head1 VERSION
 
-version 2.1204
+version 2.2015
 
 =head1 DESCRIPTION
 
-This class provides a single method shared by all mixins
+This class provides a few methods which are useful in all metaclasses.
 
 =head1 METHODS
 
-This class provides a few methods which are useful in all metaclasses.
-
-=over 4
-
-=item B<< Class::MOP::Mixin->meta >>
+=head2 Class::MOP::Mixin->meta
 
 This returns a L<Class::MOP::Class> object for the mixin class.
 
-=back
+=head2 Class::MOP::Mixin->_throw_exception
+
+Throws an exception in the L<Moose::Exception> family. This should ONLY be
+used internally -- any callers outside Class::MOP::* should be using the
+version in L<Moose::Util> instead.
 
 =head1 AUTHORS
 
@@ -53,7 +57,7 @@ This returns a L<Class::MOP::Class> object for the mixin class.
 
 =item *
 
-Stevan Little <stevan.little@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =item *
 
@@ -61,11 +65,11 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Jesse Luehrs <doy@tozt.net>
+Jesse Luehrs <doy@cpan.org>
 
 =item *
 
-Shawn M Moore <code@sartak.org>
+Shawn M Moore <sartak@cpan.org>
 
 =item *
 
@@ -81,7 +85,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
+Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
@@ -89,13 +93,13 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-Matt S Trout <mst@shadowcat.co.uk>
+Matt S Trout <mstrout@cpan.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
