@@ -1,8 +1,6 @@
 package Moose::Exception::CannotCalculateNativeType;
-BEGIN {
-  $Moose::Exception::CannotCalculateNativeType::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CannotCalculateNativeType::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Instance';
@@ -12,4 +10,5 @@ sub _build_message {
     "Cannot calculate native type for " . ref $self->instance;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
