@@ -1,12 +1,12 @@
 package Moose::Exception::NeedsTypeConstraintUnionForTypeCoercionUnion;
-BEGIN {
-  $Moose::Exception::NeedsTypeConstraintUnionForTypeCoercionUnion::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::NeedsTypeConstraintUnionForTypeCoercionUnion::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::TypeConstraint';
 
+# use Moose::Util::TypeConstraints 'find_type_constraint';
+
 has 'type_coercion_union_object' => (
     is       => 'ro',
     isa      => 'Moose::Meta::TypeCoercion::Union',
@@ -15,10 +15,11 @@ has 'type_coercion_union_object' => (
 
 sub _build_message {
     my $self = shift;
-    my $type_constraint = $self->type;
+    my $type_constraint = $self->type_name;
 
     return "You can only create a Moose::Meta::TypeCoercion::Union for a " .
            "Moose::Meta::TypeConstraint::Union, not a $type_constraint"
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
