@@ -1,8 +1,6 @@
 package Moose::Exception::RolesDoNotSupportInner;
-BEGIN {
-  $Moose::Exception::RolesDoNotSupportInner::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::RolesDoNotSupportInner::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -10,4 +8,5 @@ sub _build_message {
     "Roles cannot support 'inner'";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
