@@ -1,8 +1,6 @@
 package Moose::Exception::CannotCallAnAbstractMethod;
-BEGIN {
-  $Moose::Exception::CannotCallAnAbstractMethod::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CannotCallAnAbstractMethod::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -10,4 +8,5 @@ sub _build_message {
     "Abstract method";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
