@@ -1,8 +1,6 @@
 package Moose::Exception::MethodExpectsFewerArgs;
-BEGIN {
-  $Moose::Exception::MethodExpectsFewerArgs::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::MethodExpectsFewerArgs::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -25,4 +23,5 @@ sub _build_message {
         ( $max ? "more than $max" : 'any'). " argument".( $max == 1 ? '' : 's' );
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
