@@ -1,8 +1,6 @@
 package Moose::Exception::MustSupplyAnAttributeToConstructWith;
-BEGIN {
-  $Moose::Exception::MustSupplyAnAttributeToConstructWith::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::MustSupplyAnAttributeToConstructWith::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::ParamsHash';
@@ -17,4 +15,5 @@ sub _build_message {
     "You must supply an attribute to construct with";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
