@@ -1,8 +1,6 @@
 package Moose::Exception::DelegationToARoleWhichIsNotLoaded;
-BEGIN {
-  $Moose::Exception::DelegationToARoleWhichIsNotLoaded::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::DelegationToARoleWhichIsNotLoaded::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Attribute';
@@ -18,4 +16,5 @@ sub _build_message {
     "The ".$self->attribute->name." attribute is trying to delegate to a role which has not been loaded - ".$self->role_name;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
