@@ -1,8 +1,6 @@
 package Moose::Exception::InvalidTypeConstraint;
-BEGIN {
-  $Moose::Exception::InvalidTypeConstraint::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::InvalidTypeConstraint::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -22,4 +20,5 @@ sub _build_message {
     return "No type supplied / type is not a valid type constraint";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
