@@ -1,8 +1,6 @@
 package Moose::Exception::RoleNameRequiredForMooseMetaRole;
-BEGIN {
-  $Moose::Exception::RoleNameRequiredForMooseMetaRole::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::RoleNameRequiredForMooseMetaRole::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Role';
@@ -11,4 +9,5 @@ sub _build_message {
     "You must supply a role name to look for";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
