@@ -1,12 +1,10 @@
 package Moose::Meta::Method::Accessor::Native::Array::uniq;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Array::uniq::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Meta::Method::Accessor::Native::Array::uniq::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use strict;
 use warnings;
 
-use List::MoreUtils ();
+use List::Util 1.45 ();
 
 use Moose::Role;
 
@@ -18,7 +16,7 @@ sub _return_value {
     my $self = shift;
     my ($slot_access) = @_;
 
-    return 'List::MoreUtils::uniq @{ (' . $slot_access . ') }';
+    return 'List::Util::uniq @{ (' . $slot_access . ') }';
 }
 
 no Moose::Role;
