@@ -1,17 +1,12 @@
-
 package Moose::Meta::Class;
-BEGIN {
-  $Moose::Meta::Class::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Meta::Class::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use strict;
 use warnings;
 
 use Class::MOP;
-use Carp qw( confess );
 use Data::OptList;
-use List::Util qw( first );
-use List::MoreUtils qw( any all uniq first_index );
+use List::Util 1.33 qw( any );
 use Scalar::Util 'blessed';
 
 use Moose::Meta::Method::Overridden;
@@ -111,7 +106,9 @@ sub _anon_cache_key {
 
     my $roles = Data::OptList::mkopt(($options{roles} || []), {
         moniker  => 'role',
-        val_test => sub { ref($_[0]) eq 'HASH' },
+        name_test => sub {
+            ! ref $_[0] or blessed($_[0]) && $_[0]->isa('Moose::Meta::Role')
+        },
     });
 
     my @role_keys;
@@ -184,7 +181,7 @@ sub add_role {
     my ($self, $role) = @_;
     (blessed($role) && $role->isa('Moose::Meta::Role'))
         || throw_exception( AddRoleTakesAMooseMetaRoleInstance => role_to_be_added => $role,
-                                                                  class            => $self
+                                                                  class_name       => $self->name,
                           );
     push @{$self->roles} => $role;
 }
@@ -199,7 +196,7 @@ sub add_role_application {
     my ($self, $application) = @_;
 
     (blessed($application) && $application->isa('Moose::Meta::Role::Application::ToClass'))
-        || throw_exception( InvalidRoleApplication => class       => $self,
+        || throw_exception( InvalidRoleApplication => class_name  => $self->name,
                                                       application => $application,
                           );
 
@@ -236,7 +233,7 @@ sub does_role {
     my ($self, $role_name) = @_;
 
     (defined $role_name)
-        || throw_exception( RoleNameRequired => class => $self );
+        || throw_exception( RoleNameRequired => class_name => $self->name );
 
     foreach my $class ($self->class_precedence_list) {
         my $meta = Class::MOP::class_of($class);
@@ -256,7 +253,7 @@ sub excludes_role {
     my ($self, $role_name) = @_;
 
     (defined $role_name)
-        || throw_exception( RoleNameRequired => class => $self );
+        || throw_exception( RoleNameRequired => class_name => $self->name );
 
     foreach my $class ($self->class_precedence_list) {
         my $meta = Class::MOP::class_of($class);
@@ -336,7 +333,7 @@ sub _inline_BUILDARGS {
                 'if (scalar @_ == 1) {',
                     'if (!defined($_[0]) || ref($_[0]) ne \'HASH\') {',
                         $self->_inline_throw_exception(
-                            '"SingleParamsToNewMustBeHashRef"'
+                            'SingleParamsToNewMustBeHashRef'
                         ) . ';',
                     '}',
                     '$params = { %{ $_[0] } };',
@@ -380,16 +377,21 @@ sub _inline_check_required_attr {
     return unless $attr->can('is_required') && $attr->is_required;
     return if $attr->has_default || $attr->has_builder;
 
-    return (
-        'if (!exists $params->{\'' . $attr->init_arg . '\'}) {',
-            $self->_inline_throw_exception(
-                'AttributeIsRequired => '.
-                'params         => $params, '.
-                'class_name     => $class_name, '.
-                'attribute_name => "'.quotemeta($attr->name).'"'
-            ).';',
-        '}',
-    );
+    my $throw = $self->_inline_throw_exception(
+        'AttributeIsRequired',
+        sprintf(
+            <<'EOF', quotemeta( $attr->name ), quotemeta( $attr->init_arg ) ), );
+params             => $params,
+class_name         => $class_name,
+attribute_name     => "%s",
+attribute_init_arg => "%s",
+EOF
+
+    return sprintf( <<'EOF', quotemeta( $attr->init_arg ), $throw )
+if ( !exists $params->{"%s"} ) {
+    %s;
+}
+EOF
 }
 
 # XXX: these two are duplicated from cmop, because we have to pass the tc stuff
@@ -485,6 +487,8 @@ sub _inline_BUILDALL {
     my $self = shift;
 
     my @methods = reverse $self->find_all_methods_by_name('BUILD');
+    return () unless @methods;
+
     my @BUILD_calls;
 
     foreach my $method (@methods) {
@@ -492,7 +496,11 @@ sub _inline_BUILDALL {
             '$instance->' . $method->{class} . '::BUILD($params);';
     }
 
-    return @BUILD_calls;
+    return (
+        'if (!$params->{__no_BUILD__}) {',
+        @BUILD_calls,
+        '}',
+    );
 }
 
 sub _eval_environment {
@@ -560,7 +568,7 @@ sub superclasses {
         my ($name, $opts) = @{ $super };
         Moose::Util::_load_user_class($name, $opts);
         my $meta = Class::MOP::class_of($name);
-        throw_exception( CanExtendOnlyClasses => role => $meta )
+        throw_exception( CanExtendOnlyClasses => role_name => $meta->name )
             if $meta && $meta->isa('Moose::Meta::Role')
     }
     return $self->SUPER::superclasses(map { $_->[0] } @{ $supers });
@@ -588,8 +596,8 @@ sub add_override_method_modifier {
 
     my $existing_method = $self->get_method($name);
     (!$existing_method)
-        || throw_exception( CannotOverrideLocalMethodIsPresent => class  => $self,
-                                                                  method => $existing_method,
+        || throw_exception( CannotOverrideLocalMethodIsPresent => class_name => $self->name,
+                                                                  method     => $existing_method,
                           );
     $self->add_method($name => Moose::Meta::Method::Overridden->new(
         method  => $method,
@@ -602,8 +610,8 @@ sub add_override_method_modifier {
 sub add_augment_method_modifier {
     my ($self, $name, $method) = @_;
     my $existing_method = $self->get_method($name);
-    throw_exception( CannotAugmentIfLocalMethodPresent => class  => $self,
-                                                          method => $existing_method,
+    throw_exception( CannotAugmentIfLocalMethodPresent => class_name => $self->name,
+                                                          method     => $existing_method,
                    )
         if( $existing_method );
 
@@ -721,7 +729,7 @@ sub _process_inherited_attribute {
 
     my $inherited_attr = $self->find_attribute_by_name($attr_name);
     (defined $inherited_attr)
-        || throw_exception( NoAttributeFoundInSuperClass => class          => $self,
+        || throw_exception( NoAttributeFoundInSuperClass => class_name     => $self->name,
                                                             attribute_name => $attr_name,
                                                             params         => \%options
                           );
@@ -786,8 +794,8 @@ sub _fixup_attributes_after_rebless {
 our $error_level;
 
 sub _inline_throw_exception {
-    my ( $self, $throw_args ) = @_;
-    return 'Moose::Util::throw_exception('.$throw_args.')';
+    my ( $self, $exception_type, $throw_args ) = @_;
+    return 'die Module::Runtime::use_module("Moose::Exception::' . $exception_type . '")->new(' . ($throw_args || '') . ')';
 }
 
 1;
@@ -806,7 +814,7 @@ Moose::Meta::Class - The Moose metaclass
 
 =head1 VERSION
 
-version 2.1204
+version 2.2015
 
 =head1 DESCRIPTION
 
@@ -881,6 +889,9 @@ Each superclass can be followed by a hash reference containing a
 L<-version|Class::MOP/Class Loading Options> value. If the version
 requirement is not satisfied an error will be thrown.
 
+When you pass classes to this method, we will attempt to load them if they are
+not already loaded.
+
 =item B<< $metaclass->add_override_method_modifier($name, $sub) >>
 
 This adds an C<override> method modifier to the package.
@@ -953,7 +964,7 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =item *
 
-Stevan Little <stevan.little@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =item *
 
@@ -961,11 +972,11 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Jesse Luehrs <doy@tozt.net>
+Jesse Luehrs <doy@cpan.org>
 
 =item *
 
-Shawn M Moore <code@sartak.org>
+Shawn M Moore <sartak@cpan.org>
 
 =item *
 
@@ -981,7 +992,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
+Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
@@ -989,13 +1000,13 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-Matt S Trout <mst@shadowcat.co.uk>
+Matt S Trout <mstrout@cpan.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
