@@ -1,8 +1,6 @@
 package Moose::Exception::CoercionNeedsTypeConstraint;
-BEGIN {
-  $Moose::Exception::CoercionNeedsTypeConstraint::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CoercionNeedsTypeConstraint::VERSION = '2.1204';
+our $VERSION = '2.2015';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::InvalidAttributeOptions';
@@ -12,4 +10,5 @@ sub _build_message {
     "You cannot have coercion without specifying a type constraint on attribute (".$self->attribute_name.")";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
